<?xml version="1.0" encoding="UTF-8"?>
<!--
    Licensed Materials - Property of IBM

    BI and PM: cogadmin

    (C) Copyright IBM Corp. 2005, 2009

    US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<!--
   Copyright (C) 2008 Cognos ULC, an IBM Company. All rights reserved.
   Cognos (R) is a trademark of Cognos ULC, (formerly Cognos Incorporated).
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:uic="http://developer.cognos.com/schemas/uic/presentation/markup/" xmlns:xtsext="xalan://com.cognos.xts.ext.XTSExt" exclude-result-prefixes="xsl uic xtsext">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="uic:table">
		<xsl:variable name="isEmpty" select="not(uic:body/*)"/>
		<xsl:apply-templates select="uic:paginations">
			<xsl:with-param name="pagerName" select="uic:features/uic:name"/>
			<xsl:with-param name="interactionParams" select="uic:interactionParams"/>				
			<xsl:with-param name="sortParams" select="concat('sort_column=', uic:features/uic:sortColumn, '&amp;sort_order=', uic:features/uic:sortOrder)"/>			
		</xsl:apply-templates>
		<div class="cogstyle-table">
			<xsl:attribute name="style">
				<xsl:if test="@height != ''">height:<xsl:value-of select="@height"/>;</xsl:if>
				<xsl:choose>
					<xsl:when test="@width != ''">width:<xsl:value-of select="@width"/>;</xsl:when>
					<xsl:otherwise>width:100%;</xsl:otherwise>
				</xsl:choose>
				<!-- 
					for dialogs that show a pager, they're usually offset from the left borber. We want to keep
					all the dialogs the same, so uic:tablePadding value will get multiplied by a fixed number of pixels.
				-->
				<xsl:if test="uic:features/uic:tablePadding">margin:<xsl:value-of select="number(uic:features/uic:tablePadding) * 20"/>px;</xsl:if>
			</xsl:attribute>
			<xsl:if test="@id != ''">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<table id="_THIS_table" border="0" cellpadding="0" cellspacing="0">
				<xsl:if test="@width">
					<xsl:attribute name="width"><xsl:value-of select="number(@width)-1"/></xsl:attribute>
				</xsl:if>
				<thead class="cogstyle-table-header">
					<tr class="cogstyle-table-group" key="toggleHeader">
						<xsl:if test="uic:features/uic:type = 'checkbox'">
							<td>
								<input type="checkbox" value="">
									<xsl:attribute name="onclick">toggleCheckboxes(this, '_THIS_table')</xsl:attribute>
								</input>
							</td>
							<!-- column divider -->
							<td height="15" width="1">
								<img height="15" width="1" style="background-color:#9C9C9C" src="{$serverWebcontentPath}images/space.gif"/>
							</td>
						</xsl:if>
						<xsl:if test="uic:features/uic:type = 'group'">
							<td style="vertical-align: middle;">
								<!-- TODO: replace absolute image path with relative path -->
								<img id="_THIS_group_image_0" style="cursor:pointer" onclick="toggleAllGroups('_THIS_')">
									<xsl:attribute name="src">
										<xsl:choose>
											<xsl:when test="string(uic:features/uic:collapsed)='true'">
												<xsl:value-of select="$expandGif"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="$collapseGif"/>
											</xsl:otherwise>
										</xsl:choose>
											
									</xsl:attribute>
								</img>
							</td>
							<!-- column divider -->
							<td height="15" width="1">
								<img height="15" width="1" style="background-color:#9C9C9C" src="{$serverWebcontentPath}images/space.gif"/>
							</td>							
						</xsl:if>
						<xsl:apply-templates select="uic:header/uic:row/uic:column">
							<xsl:with-param name="type" select="'header'"/>
							<xsl:with-param name="tableFeatures">
								<xsl:copy-of select="uic:features/*"/>
								<xsl:copy-of select="uic:interactionParams"/>
							</xsl:with-param>
						</xsl:apply-templates>
					</tr>
					<!-- 1px white space under table header -->
					<!--
					<tr>						
						<td style="height:1px;background-color:white;border:0px;padding:0px">
							<xsl:attribute name="colspan"><xsl:value-of select="2*(count(uic:header/uic:row/uic:column) + number(uic:features/uic:type = 'group' or uic:features/uic:type = 'checkbox'))"/></xsl:attribute>
						</td>
					</tr>
					-->
				</thead>
				<tbody class="cogstyle-table-body">
					<xsl:attribute name="id">_THIS_tbodyElement</xsl:attribute>
					<!-- if there's nothing to display in the table, then put the 'no items' message -->
					<xsl:choose>
						<xsl:when test="$isEmpty">
							<tr>
								<td class="cogstyle-table-text cogstyle-table-empty">
									<xsl:attribute name="colspan"><xsl:value-of select="2*(count(uic:header/uic:row/uic:column) + number(uic:features/uic:type = 'group' or uic:features/uic:type = 'checkbox'))"/></xsl:attribute>
									<xsl:value-of select="$pageItemNotFound"/>
								</td>
							</tr>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="uic:body/*">
								<xsl:with-param name="tableFeatures">
									<xsl:copy-of select="uic:features/*"/>
								</xsl:with-param>
								<xsl:with-param name="withRowDetails" select="boolean(uic:body/uic:rowDetails)"/>
							</xsl:apply-templates>
						</xsl:otherwise>
					</xsl:choose>
				</tbody>
			</table>
		</div>
		<script language="javascript">
						
			<xsl:choose>
				<xsl:when test="uic:features/uic:scrollable">
					var _THIS_scrollable = true;
				</xsl:when>
				<xsl:otherwise>
					var _THIS_scrollable = false;
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="uic:features/uic:listViewSeparator = 'background'">
					var _THIS_alternate = true;
				</xsl:when>
				<xsl:otherwise>
					var _THIS_alternate = false;
				</xsl:otherwise>
			</xsl:choose>
		</script>
		<xsl:if test="uic:footer">
			<div class="cogstyle-table-footer">
				<table border="0" cellpadding="0" cellspacing="0">
					<xsl:attribute name="style">
						<xsl:choose>
							<xsl:when test="@width != ''">width:<xsl:value-of select="@width"/>;</xsl:when>
							<xsl:otherwise>width:100%;</xsl:otherwise>
						</xsl:choose>
						<!-- 
							for dialogs that show a pager, they're usually offset from the left borber. We want to keep
							all the dialogs the same, so uic:tablePadding value will get multiplied by a fixed number of pixels.
						-->
						<xsl:if test="uic:features/uic:tablePadding">margin:<xsl:value-of select="number(uic:features/uic:tablePadding) * 20"/>px;</xsl:if>
					</xsl:attribute>
					<tr>
						<xsl:attribute name="id">_THIS_footer</xsl:attribute>
						<xsl:choose>
							<xsl:when test="uic:footer != ''">
								<xsl:apply-templates select="uic:footer/uic:row/uic:column">
									<xsl:with-param name="type" select="'footer'"/>
									<xsl:with-param name="tableFeatures">
										<xsl:copy-of select="uic:features/*"/>
									</xsl:with-param>								
								</xsl:apply-templates>
							</xsl:when>
							<xsl:otherwise> <!--Default=Show TimeStamp-->
								<xsl:if test="uic:footer/@displayLastUpdate = 'true'">
									<td><xsl:value-of select="$lastRefreshed"/></td>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</tr>
				</table>
			</div>
		</xsl:if>
	</xsl:template>
					
	<!-- 
		Creates a expandable/collapsible groups
	-->
	<xsl:template match="uic:group">
		<xsl:param name="tableFeatures"/>
		<xsl:variable name="group_number" select="position()"/>
		<xsl:variable name="row_count" select="count(uic:row)"/>
		<xsl:variable name="collapsed" select="@collapsed"/>
		<xsl:variable name="collapsible" select="@collapsible"/>
		<xsl:variable name="key" select="@key"/>

		<tr class="cogstyle-table-group">
			<xsl:if test="$key">
				<xsl:attribute name="key"><xsl:value-of select="xtsext:urlencode($key)"/></xsl:attribute>
			</xsl:if>
			<td style="text-align: center;">		
				<!-- TODO: replace absolute image path with relative path -->
				<img>
					<xsl:attribute name="id">_THIS_group_image_<xsl:value-of select="$group_number"/></xsl:attribute>
					<xsl:if test="$collapsible">
						<xsl:attribute name="onclick">toggleGroup('_THIS_', '<xsl:value-of select="$group_number"/>')</xsl:attribute>
						<xsl:attribute name="style">cursor:pointer</xsl:attribute>
					</xsl:if>
					<xsl:attribute name="src"><xsl:choose><xsl:when test="$collapsed = 'true'"><xsl:value-of select="$expandGif"/></xsl:when><xsl:otherwise><xsl:value-of select="$collapseGif"/></xsl:otherwise></xsl:choose></xsl:attribute>
				</img>
			</td>
			<!-- empty spacer column -->
			<td height="15" width="1">
				<img height="15" width="1" src="{$serverWebcontentPath}images/space.gif"/>
			</td>
			<td class="cogstyle-table-group-title">
				<xsl:apply-templates select="uic:name"/>
				<xsl:apply-templates select="uic:icon"/>
			</td>
			<!-- empty spacer column -->
			<td height="15" width="1">
				<img height="15" width="1" src="{$serverWebcontentPath}images/space.gif"/>
			</td>		
			<td>
				<xsl:attribute name="colspan"><xsl:value-of select="2*(count(//uic:header/uic:row/uic:column))"/></xsl:attribute>
				<span>
					<xsl:if test="not($collapsed='true')">
						<xsl:attribute name="style">display:none</xsl:attribute>
					</xsl:if>
					<xsl:attribute name="id">_THIS_group_summary_<xsl:value-of select="$group_number"/></xsl:attribute>
					<xsl:apply-templates select="uic:summary"/>
				</span>
			</td>
		</tr>
		<xsl:apply-templates select="uic:row">
			<xsl:with-param name="groupPosition" select="$group_number"/>
			<xsl:with-param name="visible" select="not($collapsed='true')"/>
			<xsl:with-param name="tableFeatures">
				<xsl:copy-of select="$tableFeatures"/>
			</xsl:with-param>
			<xsl:with-param name="withRowDetails" select="boolean(./uic:rowDetails)"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!-- 
		Deals with rows and rowDetails
	-->
	<xsl:template match="uic:row | uic:rowDetails">
		<xsl:param name="groupPosition" select="''"/>
		<xsl:param name="visible" select="'true'"/>
		<xsl:param name="tableFeatures"/>
		<xsl:param name="withRowDetails" select="false()"/>

		<!-- 
			each item to be displayed has two elements in the DOM tree (a uic:row element and a uic:rowDetails element); 
			we need to alternate row backgrounds between even (uic:row) elements only; hence the calculation below
		-->
		<xsl:variable name="curPos">
			<xsl:choose>
				<xsl:when test="$withRowDetails = 'true'">
					<xsl:value-of select="floor(((position()-1) div 2) mod 2)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="position() mod 2"/>
				</xsl:otherwise>
			</xsl:choose>					
		</xsl:variable>
		<tr>
			<xsl:attribute name="class">
				<xsl:choose>
					<xsl:when test="@selected = 'true'">cogstyle-table-row-selected</xsl:when>
					<xsl:when test="$tableFeatures/uic:listViewSeparator = 'background' and $curPos=1">cogstyle-table-row-alternate</xsl:when>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="style">
				<xsl:if test="not($visible='true') or (local-name()='rowDetails' and @expanded != 'true')">display: none;</xsl:if>
				<xsl:if test="$tableFeatures/uic:type = 'selection'">cursor:pointer</xsl:if>
			</xsl:attribute>
			
			<!-- row id -->
			<xsl:choose>
				<xsl:when test="$groupPosition != ''">
					<xsl:attribute name="id">_THIS_group_<xsl:value-of select="concat($groupPosition, '_', position())"/></xsl:attribute>
				</xsl:when>
				<xsl:when test="@id">
					<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
				</xsl:when>
				<xsl:when test="local-name()='rowDetails'">
					<xsl:attribute name="id">_THIS_rowDetails</xsl:attribute>				
				</xsl:when>
			</xsl:choose>
			<xsl:if test="$tableFeatures/uic:type = 'selection'">
				<xsl:attribute name="onmouseover">if (this.className!='cogstyle-table-row-selected')this.className='cogstyle-table-row-alternate'</xsl:attribute>
				<xsl:attribute name="onmouseout">if (this.className!='cogstyle-table-row-selected') this.className = '<xsl:choose><xsl:when test="$tableFeatures/uic:listViewSeparator = 'background' and $curPos=1">cogstyle-table-row-alternate</xsl:when><xsl:otherwise>cogstyle-table-row-default</xsl:otherwise></xsl:choose>'</xsl:attribute>
				<xsl:attribute name="onclick">toggleHighlight('_THIS_', this, _THIS_alternate)</xsl:attribute>
			</xsl:if>
			<xsl:if test="@onmouseup">
				<xsl:attribute name="onmouseup"><xsl:value-of select="@onmouseup"/></xsl:attribute>
			</xsl:if>
			<!-- checkbox column -->
			<xsl:if test="$tableFeatures/uic:type = 'checkbox'">
				<td onclick="cancelBubble(event)">
					<xsl:choose>
						<xsl:when test="$tableFeatures/uic:listViewSeparator = 'line'">
							<xsl:attribute name="class"><xsl:value-of select="'cogstyle-table-row-separator'"/></xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class"><xsl:value-of select="'cogstyle-table-row-default'"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="@hideCheckbox != 'true' and local-name()!= 'rowDetails'">
						<xsl:variable name="id">_THIS_<xsl:value-of select="$tableFeatures/uic:name"/>
							<xsl:text>_checkbox_</xsl:text><xsl:value-of select="position()"/>
						</xsl:variable>
						<xsl:variable name="value">
							<xsl:if test="@value">
								<xsl:value-of select="@value"/>
							</xsl:if>							
						</xsl:variable>
						<input type="checkbox" name="{$id}" id="{$id}" value="{$value}" onclick="cancelBubble(event)"/>
					</xsl:if>
				</td>
				<!-- empty spacer column -->
				<td height="15" width="1">
					<img height="15" width="1" src="{$serverWebcontentPath}images/space.gif"/>
				</td>
			</xsl:if>
			<xsl:if test="$tableFeatures/uic:type = 'group'">
				<td>
					<xsl:if test="$tableFeatures/uic:listViewSeparator = 'line'">
						<xsl:attribute name="class"><xsl:value-of select="'cogstyle-table-row-separator'"/></xsl:attribute>
					</xsl:if>					
					<xsl:text>&#160;</xsl:text>
				</td>
				<!-- empty spacer column -->
				<td height="15" width="1">
					<img height="15" width="1" src="{$serverWebcontentPath}images/space.gif"/>
				</td>
			</xsl:if>

			<xsl:apply-templates select="*">
				<xsl:with-param name="tableFeatures">
					<xsl:copy-of select="$tableFeatures"/>
				</xsl:with-param>			
			</xsl:apply-templates>
		</tr>
	</xsl:template>
	<!-- 
		creates a column in the table 
	-->
	<xsl:template match="uic:column">
		<xsl:param name="type" select="''"/>
		<xsl:param name="tableFeatures"/>
		<td>
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@nowrap">
				<xsl:attribute name="nowrap">nowrap</xsl:attribute>
			</xsl:if>
			<!-- TODO: can we use an xsl:apply-templates approach to handle valid attributes? -->
			<xsl:if test="@align">
				<xsl:attribute name="align"><xsl:value-of select="@align"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@colspan">
				<xsl:attribute name="colspan"><xsl:value-of select="2*(number(@colspan))-1"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@onmouseover">
				<xsl:attribute name="onmouseover"><xsl:value-of select="@onmouseover"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@onmouseout">
				<xsl:attribute name="onmouseout"><xsl:value-of select="@onmouseout"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@onmousemove">
				<xsl:attribute name="onmousemove"><xsl:value-of select="@onmousemove"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@onclick">
				<xsl:attribute name="onclick"><xsl:value-of select="@onclick"/></xsl:attribute>
			</xsl:if>

			<xsl:if test="$tableFeatures/uic:listViewSeparator = 'line' and $type != 'header' and $type != 'footer'">
				<xsl:attribute name="class"><xsl:value-of select="'cogstyle-table-row-separator'"/></xsl:attribute>
			</xsl:if>				

			<xsl:attribute name="style">
				<xsl:value-of select="@style"/>
				<xsl:if test="@indent != ''">padding-left:<xsl:value-of select="number(@indent) * 20"/>px;</xsl:if>
			</xsl:attribute>

			<xsl:choose>
				<!-- build the sort column header-->
				<xsl:when test="@sort and @sort !=''">
					<xsl:variable name="imgSrc">
						<xsl:choose>
							<xsl:when test="$tableFeatures/uic:sortColumn and @sort = $tableFeatures/uic:sortColumn">
								<xsl:choose>
									<xsl:when test="$tableFeatures/uic:sortOrder and  $tableFeatures/uic:sortOrder = 'descending'">list_sort_descending.gif</xsl:when>
									<xsl:when test="$tableFeatures/uic:sortOrder and  $tableFeatures/uic:sortOrder = 'ascending'">list_sort_ascending.gif</xsl:when>
									<xsl:otherwise>list_sort_no.gif</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>list_sort_no.gif</xsl:otherwise>
						</xsl:choose> 		
					</xsl:variable>

					<xsl:variable name="onclick"><xsl:value-of select="concat('sortGo(_THIS_,&quot;', @sort, '&quot;, &quot;', $tableFeatures/uic:sortColumn, '&quot;,&quot;' , $tableFeatures/uic:sortOrder, '&quot;,&quot;', $tableFeatures/uic:pageParams,'&quot;,evalParm(&quot;',$tableFeatures/uic:interactionParams,'&quot;))')"/></xsl:variable>

					<table cellpadding="0" cellspacing="0" border="0">
						<tbody>
							<tr>
								<td nowrap="nowrap">
									<a href="#" onclick="{$onclick}">
										<xsl:apply-templates select="*"/>
									</a>
								</td>
								<td>
									<a href="#" onclick="{$onclick}">					
										<img src="{$skinWebcontentPath}{$imgSrc}" style="vertical-align: bottom; border: 0;">
											<xsl:if test="@iconTooltip and @iconTooltip!=''">
												<xsl:attribute name="alt"><xsl:value-of select="@iconTooltip"/></xsl:attribute>
												<xsl:attribute name="title"><xsl:value-of select="@iconTooltip"/></xsl:attribute>
											</xsl:if>
										</img>    
									</a>
								</td>
							</tr>
						</tbody>
					</table>
				</xsl:when>
				<!-- build the regular column header-->
				<xsl:otherwise>
					<xsl:apply-templates select="*"/>
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<!-- column dividers: vertical lines for header and empty space for table body -->
		<xsl:if test="$type != 'footer'">
			<td height="15">
				<xsl:if test="position() = last()">
					<xsl:attribute name="width">141px</xsl:attribute><!-- stops right-hand columns from expanding too wide -->		
				</xsl:if>	
				<table cellpadding="0" cellspacing="0" border="0">
					<tr>
						<td style="padding:0px">
							<img height="15" width="1" src="{$serverWebcontentPath}images/space.gif">
								<xsl:if test="$type = 'header' and position() != last()">
									 <xsl:attribute name="style">background-color:#9C9C9C</xsl:attribute>
								</xsl:if>
							</img>
						</td>
					</tr>
				</table>
			</td>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="uic:paginations">
		<xsl:param name="pagerName" select="''"/>
		<xsl:param name="interactionParams" select="''"/>
		<xsl:param name="sortParams" select="''"/>
		
		<xsl:variable name="javascriptEncodedPageName" select="xtsext:javascriptencode(string($pagerName))"/>
		<xsl:variable name="prev_skip">					
			<xsl:choose>
				<xsl:when test="uic:from and uic:linesPerPage and (number(uic:from) - number(uic:linesPerPage) &gt; 0)">
					<xsl:value-of select="number(uic:from) - number(uic:linesPerPage) -1"/>							
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="pageEnd">
			<xsl:choose>
				<xsl:when test="uic:to and number(uic:to)">
					<xsl:value-of select="number(uic:to)"/>							
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>					
		</xsl:variable>
		<xsl:variable name="linesPerPage">
			<xsl:choose>
				<xsl:when test="uic:linesPerPage and number(uic:linesPerPage)">
					<xsl:value-of select="number(uic:linesPerPage)"/>							
				</xsl:when>
				<xsl:otherwise>15</xsl:otherwise>
			</xsl:choose>					
		</xsl:variable>
		<script>
			var pager_validation_msg_array = new Array();
			pager_validation_msg_array['IDS_PAGER_FROM_INVALID'] = '<xsl:value-of select="$pagerFromInvalid"/>';
			pager_validation_msg_array['IDS_PAGER_TO_INVALID'] = '<xsl:value-of select="$pagerToInvalid"/>';
			pager_validation_msg_array['IDS_PAGER_ENTRIES_INVALID'] = '<xsl:value-of select="$pagerEntriesInvalid"/>';
			pager_validation_msg_array['IDS_PAGER_ENTRIES_EMPTY'] = '<xsl:value-of select="$pagerEntriesEmpty"/>';
		</script>
		<div class="cogstyle-table-paginations">
			<table cellpadding="0" cellspacing="0" style="padding:1px;height:20px;">
				<tr>
					<td class="cogstyle-form-text" nowrap="nowrap" style="padding-right:5px;">
						<xsl:value-of select="$pagerItemsMsg"/>
					</td>
					<td>
						<input id="{$pagerName}_from" name="{$pagerName}_from" type="text" size="4" class="cogstyle-form-text" maxlength="9">
							<xsl:attribute name="value">
								<xsl:if test="number(uic:from) &gt; 0"><xsl:value-of select="number(uic:from)"/></xsl:if>
							</xsl:attribute>
						</input>
					</td>
					<td class="cogstyle-form-text" style="padding-right:5px; padding-left: 5px;">-</td>
					<td>
						<input id="{$pagerName}_to" name="{$pagerName}_to" type="text" size="4" class="cogstyle-form-text" maxlength="9">
							<xsl:attribute name="value">
								<xsl:if test="number(uic:to) &gt; 0"><xsl:value-of select="number(uic:to)"/></xsl:if>
							</xsl:attribute>
						</input>
					</td>
					<td style="padding-right:8px;padding-left:2px;">
						<xsl:apply-templates select="uic:goto">
							<xsl:with-param name="imageEnabled" select="'action_go.gif'"/>
							<xsl:with-param name="defaultOnClickParams" select="$sortParams"/>
							<xsl:with-param name="interactionParams" select="$interactionParams"/>
							<xsl:with-param name="pagerName" select="$javascriptEncodedPageName"/>
							<xsl:with-param name="iconTooltip" select="$pagerGoto"/>
						</xsl:apply-templates>
					</td>
					<td nowrap="nowrap">
						<div style="height:13px;" class="rowDivider"/>
					</td>
					<td nowrap="nowrap" style="padding-left:8px;">
						<xsl:apply-templates select="uic:first">
							<xsl:with-param name="imageEnabled" select="'control_btn_top.gif'"/>
							<xsl:with-param name="imageDisabled" select="'control_btn_top_disabled.gif'"/>
							<xsl:with-param name="defaultOnClickParams" select="concat($javascriptEncodedPageName ,'_skip=0&amp;', $sortParams)"/>
							<xsl:with-param name="interactionParams" select="$interactionParams"/>
							<xsl:with-param name="iconTooltip" select="$pagerFirst"/>
						</xsl:apply-templates>
						<xsl:apply-templates select="uic:previous">
							<xsl:with-param name="imageEnabled" select="'control_btn_pageup.gif'"/>
							<xsl:with-param name="imageDisabled" select="'control_btn_pageup_disabled.gif'"/>
							<xsl:with-param name="defaultOnClickParams" select="concat($javascriptEncodedPageName ,'_skip=', number($prev_skip), '&amp;', $sortParams)"/>
							<xsl:with-param name="interactionParams" select="$interactionParams"/>
							<xsl:with-param name="iconTooltip" select="$pagerPrevious"/>
						</xsl:apply-templates>
						<xsl:apply-templates select="uic:next">
							<xsl:with-param name="imageEnabled" select="'control_btn_pagedown.gif'"/>
							<xsl:with-param name="imageDisabled" select="'control_btn_pagedown_disabled.gif'"/>
							<xsl:with-param name="defaultOnClickParams" select="concat($javascriptEncodedPageName ,'_skip=', number($pageEnd), '&amp;', $sortParams)"/>
							<xsl:with-param name="interactionParams" select="$interactionParams"/>
							<xsl:with-param name="iconTooltip" select="$pagerNext"/>
						</xsl:apply-templates>
						<xsl:apply-templates select="uic:last">
							<xsl:with-param name="imageEnabled" select="'control_btn_bottom.gif'"/>
							<xsl:with-param name="imageDisabled" select="'control_btn_bottom_disabled.gif'"/>
							<xsl:with-param name="defaultOnClickParams" select="concat($javascriptEncodedPageName ,'_skip=-', number($linesPerPage), '&amp;', $sortParams)"/>
							<xsl:with-param name="interactionParams" select="$interactionParams"/>
							<xsl:with-param name="iconTooltip" select="$pagerLast"/>							
						</xsl:apply-templates>
					</td>
				</tr>
			</table>
		</div>
		<div style="clear:both; margin-bottom: 3px;"/>
	</xsl:template>
	<xsl:template match="uic:goto | uic:first | uic:previous | uic:next | uic:last">
		<xsl:param name="imageEnabled" select="''"/>
		<xsl:param name="imageDisabled" select="''"/>
		<xsl:param name="defaultOnClickParams" select="''"/>
		<xsl:param name="interactionParams" select="''"/>
		<xsl:param name="pagerName" select="''"/>
		<xsl:param name="iconTooltip" select="''"/>
		
		<xsl:variable name="isNavgoto">
			<xsl:choose>
				<xsl:when test="local-name(.) = 'goto'">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="./uic:disabled">
				<img style="margin-right: 2px;" class="button" border="0" src="{$skinWebcontentPath}{$imageDisabled}">
					<xsl:attribute name="title"><xsl:value-of select="$iconTooltip"/></xsl:attribute>
					<xsl:attribute name="alt"><xsl:value-of select="$iconTooltip"/></xsl:attribute>
				</img>
			</xsl:when>
			<xsl:otherwise>
					<img style="margin-right: 2px; cursor: pointer;" class="button" border="0" src="{$skinWebcontentPath}{$imageEnabled}" onmousedown="this.className='button_pressed'" onmouseover="this.className='button_hover'" onmouseout="this.className='button'">
						<xsl:attribute name="title"><xsl:value-of select="$iconTooltip"/></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="$iconTooltip"/></xsl:attribute>
						<xsl:attribute name="onclick">
						<xsl:choose>
							<xsl:when test="uic:link"><xsl:value-of select="uic:link"/></xsl:when>
							<!-- build the default action -->
							<xsl:when test="$isNavgoto = 'true'">
									<xsl:text/>
										<xsl:value-of select="concat('navGo(_THIS_,&quot;', $pagerName, '&quot;, &quot;', $defaultOnClickParams, '&quot;,evalParm(&quot;',$interactionParams,'&quot;));')"/>
									<xsl:text/>
							</xsl:when>
							<xsl:when test="$defaultOnClickParams != '' or $interactionParams != ''">
								<xsl:text/>
									<xsl:value-of select="concat('navOthers(_THIS_, &quot;', $defaultOnClickParams, '&quot;,evalParm(&quot;',$interactionParams,'&quot;));')"/>
								<xsl:text/>
							</xsl:when>
						</xsl:choose>
					</xsl:attribute>
				</img>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
