<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xos="http://developer.cognos.com/schemas/xts/output/"
	xmlns:xts="http://developer.cognos.com/schemas/xts/"
	xmlns:bus="http://developer.cognos.com/schemas/bibus/3/"
	exclude-result-prefixes="xsl xsi xos xts bus">
	<xsl:output method="html" encoding="UTF-8" indent="no"/>	
	
	<xsl:variable name="webcontent" select="/fault/settings/param[@name='webcontent']"/>
	<xsl:variable name="app" select="/fault/settings/param[@name='app']"/>
	<xsl:variable name="skin" select="/fault/settings/param[@name='skin']"/>
	<xsl:variable name="web" select="/fault/settings/param[@name='web']"/>
	<xsl:variable name="gateway" select="/fault/settings/param[@name='gateway']"/>
	<xsl:variable name="pathInfo" select="/fault/settings/param[@name='pathInfo']"/>
	<xsl:variable name="browser" select="/fault/settings/param[@name='browser']"/>
	<xsl:variable name="skin_images" select="/fault/settings/param[@name='skin_images']"/>
	<xsl:variable name="isModal" select="/fault/settings/param[@name='isModal']"/>
	
	<xsl:template match="/">
		<html>
			<head>
				<meta http-equiv="expires" content="0"/>
				<link rel="stylesheet" type="text/css" href="{$web}/skins/{$skin}/portal/default.css"/>
				<link rel="stylesheet" type="text/css" href="{$web}/skins/{$skin}/fonts.css"/>
				<xsl:if test="fault[login]">
				<link rel="stylesheet" type="text/css" href="{$web}/ps/portal/css/logon.css"/>
				</xsl:if>
				
				<!-- Copy over the helper scripts and any associated form(s) -->
				<xsl:apply-templates select="fault/presentation/scripts/*" mode="scripts-and-form"/>
				
				<!-- Customization work : commented out for now -->
				<!-- <script language="javascript" src="{$webcontent}/{$app}/js/customLogin.js"></script> -->
				
				<script language="JavaScript">
					if (document.addEventListener) {
						window.addEventListener("beforeunload", function(){}, false);
					} else if (document.attachEvent) {
						window.attachEvent("onbeforeunload", function(){});
					}
				</script>
				<title><xsl:value-of select="fault/presentation/title"/></title>
			</head>
			
			<body marginwidth="3" marginheight="3" leftmargin="3" rightmargin="3" topmargin="3" bottommargin="3" 
				onload="if (window.init) init();" style="overflow:hidden">

				<xsl:choose>
				<xsl:when test="fault[login]">

				<div class="loginPage">
				<form class="loginForm" method="post" action="{concat($gateway,$pathInfo)}" name="pform">
				
				<!-- ******************* -->
				<!-- Generate the body -->
				<!-- ******************* -->
				<xsl:apply-templates/>
				
				
				<!-- ******************* -->
				<!-- Generate the footer -->
				<!-- ******************* -->
				<table border="0" width="100%" cellpadding="1" cellspacing="0" class="dialogButtonBar" id="loginFormFooterContainer" style="margin-top:20px;height:50px;">
					<tr>
						<xsl:if test="fault/presentation/actions/action[@type='ok']">
							<td id="loginOKButtonContainer">
								<input id="cmdOK" style="width:70px;"
									type="submit" class="cmdButton" onmouseover="this.className='cmdButtonOver'" 
									onmouseout="this.className='cmdButton'" 
									value="{fault/presentation/actions/action[@type='ok']/label}" 
									onclick="javascript:{fault/presentation/actions/action[@type='ok']/default-command}; return false;"/>
							</td>
						</xsl:if>
						<xsl:if test="fault/presentation/actions/action[@type='cancel']">
							<td valign="middle"  id="loginCancelButtonContainer">
								<input id="cmdCancel" style="width:70px;"
									type="button" class="cmdButton" 
									onmouseover="this.className=&#39;cmdButtonOver&#39;" 
									onmouseout="this.className=&#39;cmdButton&#39;" 
									value="{fault/presentation/actions/action[@type='cancel']/label}" 
									onclick="javascript:{fault/presentation/actions/action[@type='cancel']/default-command}; return false;"/>
							</td>
						</xsl:if>
			
						<td width="100%"/>
					</tr>
				</table>
				
				<div class="copyright" id="loginLegalContainer">
					<xsl:value-of select="fault/presentation/resources/message[@id='IDS_PROPERTY_IBM']"/><br/>
					<xsl:value-of select="fault/presentation/resources/message[@id='IDS_COPYRIGHT']"/><br/>
					<xsl:value-of select="fault/presentation/resources/message[@id='IDS_TRADEMARK']"/>		
				</div>

				</form>
				</div>

				</xsl:when>
				<xsl:otherwise>
				
				<form style="margin:0px;padding:0px;" method="post" action="{concat($gateway,$pathInfo)}" name="pform">

				<!-- ******************* -->
				<!-- Generate the header -->
				<!-- ******************* -->
				<table id="loginHeaderContainer" border="0" width="100%" cellspacing="0" cellpadding="0" class="dialogHeader" style="height:28px;">
					<tr>
						<td id="loginTitleContainer" class="dialogHeaderTitle" style="width:100%;padding-left:10px;">
							<xsl:value-of select="fault/presentation/title"/>
						</td>
						<xsl:if test="fault/presentation/actions/action[@type='help']">
							<td id="loginHelpContainer" class="dialogHeaderLink" style="white-space:nowrap">
								<a href="javascript:{fault/presentation/actions/action[@type='help']/default-command}" class="dialogHeaderLinkColor">
									<xsl:value-of select="fault/presentation/actions/action[@type='help']/label"/>
								</a>
							</td>
						</xsl:if>
						<xsl:if test="fault/presentation/actions/action[@type='close']">
							<td id="loginCloseContainer" class="dialogHeaderLink">
								<a href="javascript:{fault/presentation/actions/action[@type='close']/default-command}" class="dialogHeaderLinkColor">
									<img height="16" width="16" vspace="2" border="0"  class="dialogClose" 
										onmouseover="this.className = 'dialogCloseOver'" 
										onmouseout="this.className = 'dialogClose'"
										src="{$skin_images}close.gif">										
										<xsl:attribute name="title">
											<xsl:value-of select="fault/presentation/actions/action[@type='close']/label"/>
										</xsl:attribute>
									</img>
								</a>
							</td>
						</xsl:if>
					</tr>
				</table>
				
				
				<!-- ******************* -->
				<!-- Generate the body -->
				<!-- ******************* -->
				<xsl:apply-templates/>
				
				
				<!-- ******************* -->
				<!-- Generate the footer -->
				<!-- ******************* -->
				<table border="0" width="100%" cellpadding="1" cellspacing="0" class="dialogButtonBar" id="loginFooterContainer" style="margin-top:20px;height:50px;">
					<tr>
						<xsl:if test="fault/presentation/actions/action[@type='ok']">
							<td style="padding-left:6px;" id="loginOKButtonContainer">
								<input id="cmdOK" style="width:70px;"
									type="submit" class="cmdButton" onmouseover="this.className='cmdButtonOver'" 
									onmouseout="this.className='cmdButton'" 
									value="{fault/presentation/actions/action[@type='ok']/label}" 
									onclick="javascript:{fault/presentation/actions/action[@type='ok']/default-command}; return false;"/>
							</td>
						</xsl:if>
						<xsl:if test="fault/presentation/actions/action[@type='cancel']">
							<td valign="middle"  id="loginCancelButtonContainer">
								<input id="cmdCancel" style="width:70px;"
									type="button" class="cmdButton" 
									onmouseover="this.className=&#39;cmdButtonOver&#39;" 
									onmouseout="this.className=&#39;cmdButton&#39;" 
									value="{fault/presentation/actions/action[@type='cancel']/label}" 
									onclick="javascript:{fault/presentation/actions/action[@type='cancel']/default-command}; return false;"/>
							</td>
						</xsl:if>
						
						<td width="100%"/>
					</tr>
				</table>
				
				</form>

				</xsl:otherwise>
				</xsl:choose>
			</body>
		</html>
	</xsl:template>
	
	
	
	<!-- -->
	<!--  Render LOGIN fault -->
	<!-- -->
	<xsl:template match="fault[login]">
		<!-- original request -->
		<xsl:apply-templates select="redirect-form/*" mode="scripts-and-form"/>
	
		<xsl:variable name="promptInfo" select="login/*[local-name() = 'CAM']/*[local-name() = 'exception']/*[local-name() = 'promptInfo']"/>
				
		<div class="dialogHeaderText" id="loginIntroTextContainer">
			<xsl:for-each select="$promptInfo/*[local-name() = 'captions']/*">
				<xsl:value-of select="concat(., ' ')"/>
			</xsl:for-each>			
		</div>
				
		<div id="loginPromptContainer">
			<xsl:for-each select="$promptInfo/*[local-name() = 'displayObjects']/*[local-name() = 'item'][@xsi:type = 'bus:displayObject']">			
				<xsl:choose>
					
					<!-- Hidden fields -->
					<xsl:when test="*[local-name() = 'type'] = 'hidden'">
						<input type="hidden" name="{*[local-name() = 'name']}" value="{*[local-name() = 'value']}"/>
					</xsl:when>					
					
					<xsl:when test="*[local-name() = 'type'] = 'singleselect'">									
						<div class="formLabel" style="padding-top:10px;"><xsl:value-of select="*[local-name() = 'caption']"/></div>
						<div>
							<select name="{*[local-name() = 'name']}" onkeypress="submitThis(event)">
								<xsl:for-each select="*[local-name() = 'promptOptions']/*">
									<option value="{*[local-name() = 'id']}">
										<xsl:if test="*[local-name() = 'default'] = 'true'">
											<xsl:attribute name="selected">selected</xsl:attribute>
										</xsl:if>
										<xsl:value-of select="*[local-name() = 'value']"/>
									</option>
								</xsl:for-each>
							</select>
							<script language="JavaScript">
								function submitThis(e)
								{
									var sKey = null;
									if (window.event) //IE, Safari
										sKey = window.event.keyCode;
									else
										sKey = e.which; //Moz
									if ((sKey == '13') || (sKey=='32'))
										window.document.pform.submit();
								}
							</script>			
						</div>													
					</xsl:when>										
											
					<!-- Static display fields -->
					<xsl:when test="*[local-name() = 'type'] = 'display'">	
						<div class="formLabel" style="padding-top:10px;"><xsl:value-of select="*[local-name() = 'caption']"/></div>							
						<div class="formText"><xsl:value-of select="*[local-name() = 'value']"/></div>											
					</xsl:when>										
														
					<!-- Password/Text fields -->
					<xsl:otherwise>	
						<div class="formLabel" style="padding-top:10px;"><xsl:value-of select="*[local-name() = 'caption']"/></div>
						<div class="formText">
							<input name="{*[local-name() = 'name']}" value="{*[local-name() = 'value']}">
								<xsl:if test="contains(*[local-name() = 'type'], 'textnoecho')">
									<xsl:attribute name="type">password</xsl:attribute>
									<xsl:attribute name="autocomplete">off</xsl:attribute>
								</xsl:if>
								<xsl:if test="*[local-name() = 'type']='text'">
									<xsl:attribute name="type">text</xsl:attribute>
								</xsl:if>
							</input>
						</div>													 						
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			
		</div>
	</xsl:template>
	
	
	
	
	
	
	
	
	
	<!-- -->
	<!--  Render ERROR fault -->
	<!-- -->
	<xsl:template match="fault[error]">
		<table width="100%" border="0" cellspacing="0" cellpadding="0">
			<tr>
				<td>
					<img src="{$webcontent}/images/space.gif" alt="" width="1" height="10"/>
				</td>
			</tr>
		</table>
		
		<table width="100%" border="0" cellspacing="0" cellpadding="0" style="padding-left:5px;">
			<tr>
				<td class="dialogHeaderText">
					<xsl:value-of select="./error/errorCodeString"/>
				</td>
			</tr>
		</table>
		
		<table width="100%" border="0" cellspacing="0" cellpadding="0">
			<tr>
				<td>
					<img src="{$webcontent}/images/space.gif" alt="" width="1" height="10"/>
				</td>
			</tr>
		</table>
		
		<table width="100%" border="0" cellspacing="0" cellpadding="0">
			<tr>
				<td>
					<table width="100%" border="0" cellspacing="0" cellpadding="3">
						<tr>
							<td width="1" height="1">
								<img src="{$webcontent}/images/space.gif" width="1" height="1"/>
							</td>
							<td width="100%">
								<table border="0" cellspacing="0" cellpadding="0">
									<tr>
										<td>
											<img src="{$webcontent}/{$app}/images/msg_error.gif" alt="" width="32" height="32" border="0"/>
										</td>
										<td class="formText">&#160;&#160;&#160;</td>
										<td class="formText" valign="top">
											<xsl:value-of select="./error/message"/>
										</td>
									</tr>
								</table>
							</td>
						</tr>
					</table>
					
					<xsl:if test="count(./error/details) > 0">
						<script type="text/javascript" language="JavaScript">
							var imgExpand   = new Image();
							var imgCollapse = new Image();
							imgExpand.src = "<xsl:value-of select="$skin_images"/>prompt_option_expand.gif";
							imgCollapse.src   = "<xsl:value-of select="$skin_images"/>prompt_option_collapse.gif";
								
							function toggleDynamicSection(name) {
								var img = document.getElementById("img_" + name);
								
								if(document.getElementById(name).style.display == 'none') {
									document.getElementById(name).style.display	= "";
									img.src = imgCollapse.src;
								} else {
									document.getElementById(name).style.display	= "none";
									img.src = imgExpand.src;
								}
							}
						</script>
		
						<table border="0" cellpadding="0" cellspacing="0" style="padding-bottom:5px; padding-top:5px;">
							<tr>
								<td>
									<img src="{$webcontent}/images/space.gif" alt="" width="30" height="30" border="0"/>
								</td>
								<td class="formText">&#160;&#160;&#160;</td>
								<td>
									<table>
										<tr>
											<td class="formText" valign="bottom" nowrap="nowrap" style="padding-left:10px;">
												<a href="javascript:toggleDynamicSection('errorPanel')">
													<xsl:value-of select="presentation/resources/message[@id='IDS_FAULT_DETAILS']"/>
												</a>
												<a href="javascript:toggleDynamicSection('errorPanel');{@onclick}">
													<img name="img_errorPanel" id="img_errorPanel" border="0">
														<xsl:attribute name="src"><xsl:value-of select="$skin_images"/>prompt_option_expand.gif</xsl:attribute>
													</img>						
												</a>
											</td>
										</tr>
										<tr>
											<td>
												<div id="errorPanel" class="errorPanel" style="display:none">
													<xsl:value-of select="./error/details"/>
												</div>
											</td>
										</tr>
									</table>
								</td>
							</tr>
						</table>
						
					</xsl:if>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="*" mode="scripts-and-form">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates mode="scripts-and-form"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="input" mode="scripts-and-form">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="text()"/>
</xsl:stylesheet>
